========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.db.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

===============================================
 oslo.db -- OpenStack Database Pattern Library
===============================================

.. image:: https://img.shields.io/pypi/v/oslo.db.svg
    :target: https://pypi.org/project/oslo.db/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.db.svg
    :target: https://pypi.org/project/oslo.db/
    :alt: Downloads

The oslo db (database) handling library, provides database
connectivity to different database backends and various other helper
utils.

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.db/latest
* Source: https://git.openstack.org/cgit/openstack/oslo.db
* Bugs: https://bugs.launchpad.net/oslo.db
* Release notes:  https://docs.openstack.org/releasenotes/oslo.db/
